diff --git a/io_scene_obj/import_obj.py b/io_scene_obj/import_obj.py
index d51d62c7b2c481344b39d33ae4a70deac8e0e8cb..a29575222fd972a182d620c85c269932c27e121c 100644
--- a/io_scene_obj/import_obj.py
+++ b/io_scene_obj/import_obj.py
@@ -592,7 +592,7 @@ def create_mesh(new_objects,
 
     for i, face in enumerate(faces):
         if len(face[0]) < 2:
-            pass  # raise "bad face"
+            pass  # raise Exception("bad face")
         elif len(face[0]) == 2:
             if use_edges:
                 edges.append(face[0])
diff --git a/io_anim_bvh/import_bvh.py b/io_anim_bvh/import_bvh.py
index da4ece1187088b3a9bd33f436e9b6a14593a9b07..50ae4bd797fbc4ae7f4e2aed56f5719815991459 100644
--- a/io_anim_bvh/import_bvh.py
+++ b/io_anim_bvh/import_bvh.py
@@ -110,7 +110,7 @@ def read_bvh(context, file_path, rotate_mode='XYZ', global_scale=1.0):
         #print 'Importing the BVH Hierarchy for:', file_path
         pass
     else:
-        raise 'ERROR: This is not a BVH file'
+        raise Exception("This is not a BVH file")
 
     bvh_nodes = {None: None}
     bvh_nodes_serial = [None]
@@ -274,7 +274,7 @@ def read_bvh(context, file_path, rotate_mode='XYZ', global_scale=1.0):
             else:
                 # allow this, see above
                 #if not bvh_node.children:
                 #	raise 'error, bvh node has no end and no children. bad file'
 
                 # Removed temp for now
                 rest_tail_world = Vector((0.0, 0.0, 0.0))
@@ -274,7 +274,7 @@ def read_bvh(context, file_path, rotate_mode='XYZ', global_scale=1.0):
                 # allow this, see above
                 #if not bvh_node.children:
-                #	raise 'error, bvh node has no end and no children. bad file'
+                #	raise Exception("bvh node has no end and no children. bad file")
 
                 # Removed temp for now